@@ -32,7 +32,7 @@
 #'                         
 #' ## poll the job to check its status
 #' ## its done when job$status$state == "DONE"
-#' bqr_get_job("your_project", job$jobReference$jobId)
+#' bqr_get_job("your_project", job)
 #' 
 #' ##once done, the query results are in "bigResultTable"
 #' ## extract that table to GoogleCloudStorage:
@@ -48,12 +48,14 @@
 #' ## its done when job$status$state == "DONE"
 #' bqr_get_job("your_project", job_extract$jobReference$jobId)
 #' 
+#' You should also see the extract in the Google Cloud Storage bucket
+#' googleCloudStorageR::gcs_list_objects("your_cloud_storage_bucket_name")
+#' 
 #' ## to download via a URL and not logging in via Google Cloud Storage interface:
 #' ## Use an email that is Google account enabled
 #' ## Requires scopes:
 #' ##  https://www.googleapis.com/auth/devstorage.full_control
 #' ##  https://www.googleapis.com/auth/cloud-platform
-#' ## set via options("bigQueryR.scopes") and reauthenticate if needed
 #' 
 #' download_url <- bqr_grant_extract_access(job_extract, "your@email.com")
 #' 
@@ -65,8 +67,8 @@
 #'
 #' @family BigQuery asynch query functions  
 #' @export
-bqr_extract_data <- function(projectId, 
-                             datasetId, 
+bqr_extract_data <- function(projectId = bq_get_global_project(), 
+                             datasetId = bq_get_global_dataset(), 
                              tableId,
                              cloudStorageBucket,
                              filename = paste0("big-query-extract-",
@@ -82,6 +84,8 @@ bqr_extract_data <- function(projectId,
   compression <- match.arg(compression)
   destinationFormat <- match.arg(destinationFormat)
   
+  check_gcs_auth()
+  
   stopifnot(inherits(projectId, "character"),
             inherits(datasetId, "character"),
             inherits(tableId, "character"),
@@ -132,8 +136,8 @@ bqr_extract_data <- function(projectId,
                the_body = config)
   
   if(req$status_code == 200){
-    myMessage("Extract request successful", level=2)
-    out <- req$content
+    myMessage("Extract request successful, use bqr_wait_for_job() to know when it is ready.", level=3)
+    out <- as.job(req$content)
   } else {
     stop("Error in extraction job")
     # out <- FALSE
@@ -164,6 +168,8 @@ bqr_download_extract <- function(extractJob,
     stop("Job not done")
   }
   
+  check_gcs_auth()
+  
   ## if multiple files, create the suffixs 000000000000, 000000000001, etc.
   file_suffix <- make_suffix(extractJob$statistics$extract$destinationUriFileCounts)
   
@@ -260,6 +266,10 @@ bqr_download_extract <- function(extractJob,
 #' @export
 bqr_grant_extract_access <- function(extractJob, email){
   
+  check_gcs_auth()
+  
+  stopifnot(is.job(extractJob))
+  
   if(extractJob$status$state != "DONE"){
     stop("Job not done")
   }
@@ -281,19 +291,20 @@ bqr_grant_extract_access <- function(extractJob, email){
   
   # helper function with prefilled params
   updateAccess <- function(object){
-    gcs_update_acl(bucket = bucketnames[1], # should all be in same bucket
-                   object = object,
-                   entity = email,
-                   entity_type = "user",
-                   role = "READER")
+    googleCloudStorageR::gcs_update_object_acl(
+      object_name = object,
+      bucket = bucketnames[[1]],
+      entity = email,
+      entity_type = "user",
+      role = "READER"
+    )
   }
   
   result <- vapply(objectnames, updateAccess, logical(1))
   
   ## the download URLs
-  downloadUri <- paste0("https://storage.cloud.google.com", 
-                        "/",bucketnames,
-                        "/", objectnames)
+  downloadUri <- googleCloudStorageR::gcs_download_url(object_name = objectnames, 
+                                                       bucket = bucketnames)
   
   if(all(result)){
     out <- downloadUri
@@ -312,4 +323,5 @@ make_suffix <- function(destinationUriFileCount){
   along <- 0:(as.numeric(destinationUriFileCount)-1)
 
   vapply(along, suff, "000000000000")
-}
\ No newline at end of file
+}
+
